# coding: utf-8

"""
    Kill Bill

    Kill Bill is an open-source billing and payments platform  # noqa: E501

    OpenAPI spec version: 0.22.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class UsagePrice(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'usage_name': 'str',
        'usage_type': 'str',
        'billing_mode': 'str',
        'tier_block_policy': 'str',
        'tier_prices': 'list[TierPrice]'
    }

    attribute_map = {
        'usage_name': 'usageName',
        'usage_type': 'usageType',
        'billing_mode': 'billingMode',
        'tier_block_policy': 'tierBlockPolicy',
        'tier_prices': 'tierPrices'
    }

    def __init__(self, usage_name=None, usage_type=None, billing_mode=None, tier_block_policy=None, tier_prices=None):  # noqa: E501
        """UsagePrice - a model defined in Swagger"""  # noqa: E501
        self._usage_name = None
        self._usage_type = None
        self._billing_mode = None
        self._tier_block_policy = None
        self._tier_prices = None
        self.discriminator = None
        if usage_name is not None:
            self.usage_name = usage_name
        if usage_type is not None:
            self.usage_type = usage_type
        if billing_mode is not None:
            self.billing_mode = billing_mode
        if tier_block_policy is not None:
            self.tier_block_policy = tier_block_policy
        if tier_prices is not None:
            self.tier_prices = tier_prices

    @property
    def usage_name(self):
        """Gets the usage_name of this UsagePrice.  # noqa: E501


        :return: The usage_name of this UsagePrice.  # noqa: E501
        :rtype: str
        """
        return self._usage_name

    @usage_name.setter
    def usage_name(self, usage_name):
        """Sets the usage_name of this UsagePrice.


        :param usage_name: The usage_name of this UsagePrice.  # noqa: E501
        :type: str
        """

        self._usage_name = usage_name

    @property
    def usage_type(self):
        """Gets the usage_type of this UsagePrice.  # noqa: E501


        :return: The usage_type of this UsagePrice.  # noqa: E501
        :rtype: str
        """
        return self._usage_type

    @usage_type.setter
    def usage_type(self, usage_type):
        """Sets the usage_type of this UsagePrice.


        :param usage_type: The usage_type of this UsagePrice.  # noqa: E501
        :type: str
        """
        allowed_values = ["CAPACITY", "CONSUMABLE"]  # noqa: E501
        if usage_type not in allowed_values:
            raise ValueError(
                "Invalid value for `usage_type` ({0}), must be one of {1}"  # noqa: E501
                .format(usage_type, allowed_values)
            )

        self._usage_type = usage_type

    @property
    def billing_mode(self):
        """Gets the billing_mode of this UsagePrice.  # noqa: E501


        :return: The billing_mode of this UsagePrice.  # noqa: E501
        :rtype: str
        """
        return self._billing_mode

    @billing_mode.setter
    def billing_mode(self, billing_mode):
        """Sets the billing_mode of this UsagePrice.


        :param billing_mode: The billing_mode of this UsagePrice.  # noqa: E501
        :type: str
        """
        allowed_values = ["IN_ADVANCE", "IN_ARREAR"]  # noqa: E501
        if billing_mode not in allowed_values:
            raise ValueError(
                "Invalid value for `billing_mode` ({0}), must be one of {1}"  # noqa: E501
                .format(billing_mode, allowed_values)
            )

        self._billing_mode = billing_mode

    @property
    def tier_block_policy(self):
        """Gets the tier_block_policy of this UsagePrice.  # noqa: E501


        :return: The tier_block_policy of this UsagePrice.  # noqa: E501
        :rtype: str
        """
        return self._tier_block_policy

    @tier_block_policy.setter
    def tier_block_policy(self, tier_block_policy):
        """Sets the tier_block_policy of this UsagePrice.


        :param tier_block_policy: The tier_block_policy of this UsagePrice.  # noqa: E501
        :type: str
        """
        allowed_values = ["ALL_TIERS", "TOP_TIER"]  # noqa: E501
        if tier_block_policy not in allowed_values:
            raise ValueError(
                "Invalid value for `tier_block_policy` ({0}), must be one of {1}"  # noqa: E501
                .format(tier_block_policy, allowed_values)
            )

        self._tier_block_policy = tier_block_policy

    @property
    def tier_prices(self):
        """Gets the tier_prices of this UsagePrice.  # noqa: E501


        :return: The tier_prices of this UsagePrice.  # noqa: E501
        :rtype: list[TierPrice]
        """
        return self._tier_prices

    @tier_prices.setter
    def tier_prices(self, tier_prices):
        """Sets the tier_prices of this UsagePrice.


        :param tier_prices: The tier_prices of this UsagePrice.  # noqa: E501
        :type: list[TierPrice]
        """

        self._tier_prices = tier_prices

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UsagePrice, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UsagePrice):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Kill Bill

    Kill Bill is an open-source billing and payments platform  # noqa: E501

    OpenAPI spec version: 0.22.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from killbill.api_client import ApiClient


class CatalogApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def add_simple_plan(self, body, x_killbill_created_by, **kwargs):  # noqa: E501
        """Add a simple plan entry in the current version of the catalog  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_simple_plan(body, x_killbill_created_by, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param SimplePlan body: (required)
        :param str x_killbill_created_by: (required)
        :param str x_killbill_reason:
        :param str x_killbill_comment:
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.add_simple_plan_with_http_info(body, x_killbill_created_by, **kwargs)  # noqa: E501
        else:
            (data) = self.add_simple_plan_with_http_info(body, x_killbill_created_by, **kwargs)  # noqa: E501
            return data

    def add_simple_plan_with_http_info(self, body, x_killbill_created_by, **kwargs):  # noqa: E501
        """Add a simple plan entry in the current version of the catalog  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_simple_plan_with_http_info(body, x_killbill_created_by, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param SimplePlan body: (required)
        :param str x_killbill_created_by: (required)
        :param str x_killbill_reason:
        :param str x_killbill_comment:
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'x_killbill_created_by', 'x_killbill_reason', 'x_killbill_comment']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_simple_plan" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `add_simple_plan`")  # noqa: E501
        # verify the required parameter 'x_killbill_created_by' is set
        if ('x_killbill_created_by' not in params or
                params['x_killbill_created_by'] is None):
            raise ValueError("Missing the required parameter `x_killbill_created_by` when calling `add_simple_plan`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'x_killbill_created_by' in params:
            header_params['X-Killbill-CreatedBy'] = params['x_killbill_created_by']  # noqa: E501
        if 'x_killbill_reason' in params:
            header_params['X-Killbill-Reason'] = params['x_killbill_reason']  # noqa: E501
        if 'x_killbill_comment' in params:
            header_params['X-Killbill-Comment'] = params['x_killbill_comment']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Killbill Api Key', 'Killbill Api Secret', 'basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/1.0/kb/catalog/simplePlan', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_catalog(self, x_killbill_created_by, **kwargs):  # noqa: E501
        """Delete all versions for a per tenant catalog  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_catalog(x_killbill_created_by, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_killbill_created_by: (required)
        :param str x_killbill_reason:
        :param str x_killbill_comment:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_catalog_with_http_info(x_killbill_created_by, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_catalog_with_http_info(x_killbill_created_by, **kwargs)  # noqa: E501
            return data

    def delete_catalog_with_http_info(self, x_killbill_created_by, **kwargs):  # noqa: E501
        """Delete all versions for a per tenant catalog  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_catalog_with_http_info(x_killbill_created_by, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_killbill_created_by: (required)
        :param str x_killbill_reason:
        :param str x_killbill_comment:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['x_killbill_created_by', 'x_killbill_reason', 'x_killbill_comment']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_catalog" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'x_killbill_created_by' is set
        if ('x_killbill_created_by' not in params or
                params['x_killbill_created_by'] is None):
            raise ValueError("Missing the required parameter `x_killbill_created_by` when calling `delete_catalog`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'x_killbill_created_by' in params:
            header_params['X-Killbill-CreatedBy'] = params['x_killbill_created_by']  # noqa: E501
        if 'x_killbill_reason' in params:
            header_params['X-Killbill-Reason'] = params['x_killbill_reason']  # noqa: E501
        if 'x_killbill_comment' in params:
            header_params['X-Killbill-Comment'] = params['x_killbill_comment']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['Killbill Api Key', 'Killbill Api Secret', 'basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/1.0/kb/catalog', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_available_addons(self, **kwargs):  # noqa: E501
        """Retrieve available add-ons for a given product  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_available_addons(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str base_product_name:
        :param str price_list_name:
        :param str account_id:
        :return: list[PlanDetail]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_available_addons_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_available_addons_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_available_addons_with_http_info(self, **kwargs):  # noqa: E501
        """Retrieve available add-ons for a given product  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_available_addons_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str base_product_name:
        :param str price_list_name:
        :param str account_id:
        :return: list[PlanDetail]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['base_product_name', 'price_list_name', 'account_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_available_addons" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'base_product_name' in params:
            query_params.append(('baseProductName', params['base_product_name']))  # noqa: E501
        if 'price_list_name' in params:
            query_params.append(('priceListName', params['price_list_name']))  # noqa: E501
        if 'account_id' in params:
            query_params.append(('accountId', params['account_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Killbill Api Key', 'Killbill Api Secret', 'basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/1.0/kb/catalog/availableAddons', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[PlanDetail]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_available_base_plans(self, **kwargs):  # noqa: E501
        """Retrieve available base plans  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_available_base_plans(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str account_id:
        :return: list[PlanDetail]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_available_base_plans_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_available_base_plans_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_available_base_plans_with_http_info(self, **kwargs):  # noqa: E501
        """Retrieve available base plans  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_available_base_plans_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str account_id:
        :return: list[PlanDetail]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['account_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_available_base_plans" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'account_id' in params:
            query_params.append(('accountId', params['account_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Killbill Api Key', 'Killbill Api Secret', 'basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/1.0/kb/catalog/availableBasePlans', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[PlanDetail]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_catalog_json(self, **kwargs):  # noqa: E501
        """Retrieve the catalog as JSON  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_catalog_json(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param datetime requested_date:
        :param str account_id:
        :return: list[Catalog]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_catalog_json_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_catalog_json_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_catalog_json_with_http_info(self, **kwargs):  # noqa: E501
        """Retrieve the catalog as JSON  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_catalog_json_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param datetime requested_date:
        :param str account_id:
        :return: list[Catalog]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['requested_date', 'account_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_catalog_json" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'requested_date' in params:
            query_params.append(('requestedDate', params['requested_date']))  # noqa: E501
        if 'account_id' in params:
            query_params.append(('accountId', params['account_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Killbill Api Key', 'Killbill Api Secret', 'basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/1.0/kb/catalog', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Catalog]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_catalog_versions(self, **kwargs):  # noqa: E501
        """Retrieve a list of catalog versions  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_catalog_versions(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str account_id:
        :return: list[datetime]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_catalog_versions_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_catalog_versions_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_catalog_versions_with_http_info(self, **kwargs):  # noqa: E501
        """Retrieve a list of catalog versions  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_catalog_versions_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str account_id:
        :return: list[datetime]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['account_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_catalog_versions" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'account_id' in params:
            query_params.append(('accountId', params['account_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Killbill Api Key', 'Killbill Api Secret', 'basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/1.0/kb/catalog/versions', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[datetime]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_catalog_xml(self, **kwargs):  # noqa: E501
        """Retrieve the full catalog as XML  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_catalog_xml(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param datetime requested_date:
        :param str account_id:
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_catalog_xml_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_catalog_xml_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_catalog_xml_with_http_info(self, **kwargs):  # noqa: E501
        """Retrieve the full catalog as XML  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_catalog_xml_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param datetime requested_date:
        :param str account_id:
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['requested_date', 'account_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_catalog_xml" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'requested_date' in params:
            query_params.append(('requestedDate', params['requested_date']))  # noqa: E501
        if 'account_id' in params:
            query_params.append(('accountId', params['account_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Killbill Api Key', 'Killbill Api Secret', 'basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/1.0/kb/catalog/xml', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_phase_for_subscription_and_date(self, **kwargs):  # noqa: E501
        """Retrieve phase for a given subscription and date  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_phase_for_subscription_and_date(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str subscription_id:
        :param date requested_date:
        :return: Phase
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_phase_for_subscription_and_date_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_phase_for_subscription_and_date_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_phase_for_subscription_and_date_with_http_info(self, **kwargs):  # noqa: E501
        """Retrieve phase for a given subscription and date  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_phase_for_subscription_and_date_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str subscription_id:
        :param date requested_date:
        :return: Phase
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['subscription_id', 'requested_date']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_phase_for_subscription_and_date" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'subscription_id' in params:
            query_params.append(('subscriptionId', params['subscription_id']))  # noqa: E501
        if 'requested_date' in params:
            query_params.append(('requestedDate', params['requested_date']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Killbill Api Key', 'Killbill Api Secret', 'basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/1.0/kb/catalog/phase', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Phase',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_plan_for_subscription_and_date(self, **kwargs):  # noqa: E501
        """Retrieve plan for a given subscription and date  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_plan_for_subscription_and_date(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str subscription_id:
        :param date requested_date:
        :return: Plan
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_plan_for_subscription_and_date_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_plan_for_subscription_and_date_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_plan_for_subscription_and_date_with_http_info(self, **kwargs):  # noqa: E501
        """Retrieve plan for a given subscription and date  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_plan_for_subscription_and_date_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str subscription_id:
        :param date requested_date:
        :return: Plan
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['subscription_id', 'requested_date']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_plan_for_subscription_and_date" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'subscription_id' in params:
            query_params.append(('subscriptionId', params['subscription_id']))  # noqa: E501
        if 'requested_date' in params:
            query_params.append(('requestedDate', params['requested_date']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Killbill Api Key', 'Killbill Api Secret', 'basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/1.0/kb/catalog/plan', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Plan',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_price_list_for_subscription_and_date(self, **kwargs):  # noqa: E501
        """Retrieve priceList for a given subscription and date  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_price_list_for_subscription_and_date(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str subscription_id:
        :param date requested_date:
        :return: PriceList
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_price_list_for_subscription_and_date_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_price_list_for_subscription_and_date_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_price_list_for_subscription_and_date_with_http_info(self, **kwargs):  # noqa: E501
        """Retrieve priceList for a given subscription and date  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_price_list_for_subscription_and_date_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str subscription_id:
        :param date requested_date:
        :return: PriceList
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['subscription_id', 'requested_date']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_price_list_for_subscription_and_date" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'subscription_id' in params:
            query_params.append(('subscriptionId', params['subscription_id']))  # noqa: E501
        if 'requested_date' in params:
            query_params.append(('requestedDate', params['requested_date']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Killbill Api Key', 'Killbill Api Secret', 'basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/1.0/kb/catalog/priceList', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PriceList',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_product_for_subscription_and_date(self, **kwargs):  # noqa: E501
        """Retrieve product for a given subscription and date  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_product_for_subscription_and_date(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str subscription_id:
        :param date requested_date:
        :return: Product
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_product_for_subscription_and_date_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_product_for_subscription_and_date_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_product_for_subscription_and_date_with_http_info(self, **kwargs):  # noqa: E501
        """Retrieve product for a given subscription and date  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_product_for_subscription_and_date_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str subscription_id:
        :param date requested_date:
        :return: Product
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['subscription_id', 'requested_date']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_product_for_subscription_and_date" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'subscription_id' in params:
            query_params.append(('subscriptionId', params['subscription_id']))  # noqa: E501
        if 'requested_date' in params:
            query_params.append(('requestedDate', params['requested_date']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Killbill Api Key', 'Killbill Api Secret', 'basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/1.0/kb/catalog/product', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Product',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def upload_catalog_xml(self, body, x_killbill_created_by, **kwargs):  # noqa: E501
        """Upload the full catalog as XML  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.upload_catalog_xml(body, x_killbill_created_by, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str body: (required)
        :param str x_killbill_created_by: (required)
        :param str x_killbill_reason:
        :param str x_killbill_comment:
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.upload_catalog_xml_with_http_info(body, x_killbill_created_by, **kwargs)  # noqa: E501
        else:
            (data) = self.upload_catalog_xml_with_http_info(body, x_killbill_created_by, **kwargs)  # noqa: E501
            return data

    def upload_catalog_xml_with_http_info(self, body, x_killbill_created_by, **kwargs):  # noqa: E501
        """Upload the full catalog as XML  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.upload_catalog_xml_with_http_info(body, x_killbill_created_by, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str body: (required)
        :param str x_killbill_created_by: (required)
        :param str x_killbill_reason:
        :param str x_killbill_comment:
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'x_killbill_created_by', 'x_killbill_reason', 'x_killbill_comment']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method upload_catalog_xml" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `upload_catalog_xml`")  # noqa: E501
        # verify the required parameter 'x_killbill_created_by' is set
        if ('x_killbill_created_by' not in params or
                params['x_killbill_created_by'] is None):
            raise ValueError("Missing the required parameter `x_killbill_created_by` when calling `upload_catalog_xml`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'x_killbill_created_by' in params:
            header_params['X-Killbill-CreatedBy'] = params['x_killbill_created_by']  # noqa: E501
        if 'x_killbill_reason' in params:
            header_params['X-Killbill-Reason'] = params['x_killbill_reason']  # noqa: E501
        if 'x_killbill_comment' in params:
            header_params['X-Killbill-Comment'] = params['x_killbill_comment']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['text/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Killbill Api Key', 'Killbill Api Secret', 'basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/1.0/kb/catalog/xml', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Kill Bill

    Kill Bill is an open-source billing and payments platform  # noqa: E501

    OpenAPI spec version: 0.22.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Tier(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'limits': 'list[Limit]',
        'fixed_price': 'list[Price]',
        'recurring_price': 'list[Price]',
        'blocks': 'list[TieredBlock]'
    }

    attribute_map = {
        'limits': 'limits',
        'fixed_price': 'fixedPrice',
        'recurring_price': 'recurringPrice',
        'blocks': 'blocks'
    }

    def __init__(self, limits=None, fixed_price=None, recurring_price=None, blocks=None):  # noqa: E501
        """Tier - a model defined in Swagger"""  # noqa: E501
        self._limits = None
        self._fixed_price = None
        self._recurring_price = None
        self._blocks = None
        self.discriminator = None
        if limits is not None:
            self.limits = limits
        if fixed_price is not None:
            self.fixed_price = fixed_price
        if recurring_price is not None:
            self.recurring_price = recurring_price
        if blocks is not None:
            self.blocks = blocks

    @property
    def limits(self):
        """Gets the limits of this Tier.  # noqa: E501


        :return: The limits of this Tier.  # noqa: E501
        :rtype: list[Limit]
        """
        return self._limits

    @limits.setter
    def limits(self, limits):
        """Sets the limits of this Tier.


        :param limits: The limits of this Tier.  # noqa: E501
        :type: list[Limit]
        """

        self._limits = limits

    @property
    def fixed_price(self):
        """Gets the fixed_price of this Tier.  # noqa: E501


        :return: The fixed_price of this Tier.  # noqa: E501
        :rtype: list[Price]
        """
        return self._fixed_price

    @fixed_price.setter
    def fixed_price(self, fixed_price):
        """Sets the fixed_price of this Tier.


        :param fixed_price: The fixed_price of this Tier.  # noqa: E501
        :type: list[Price]
        """

        self._fixed_price = fixed_price

    @property
    def recurring_price(self):
        """Gets the recurring_price of this Tier.  # noqa: E501


        :return: The recurring_price of this Tier.  # noqa: E501
        :rtype: list[Price]
        """
        return self._recurring_price

    @recurring_price.setter
    def recurring_price(self, recurring_price):
        """Sets the recurring_price of this Tier.


        :param recurring_price: The recurring_price of this Tier.  # noqa: E501
        :type: list[Price]
        """

        self._recurring_price = recurring_price

    @property
    def blocks(self):
        """Gets the blocks of this Tier.  # noqa: E501


        :return: The blocks of this Tier.  # noqa: E501
        :rtype: list[TieredBlock]
        """
        return self._blocks

    @blocks.setter
    def blocks(self, blocks):
        """Sets the blocks of this Tier.


        :param blocks: The blocks of this Tier.  # noqa: E501
        :type: list[TieredBlock]
        """

        self._blocks = blocks

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Tier, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Tier):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Kill Bill

    Kill Bill is an open-source billing and payments platform  # noqa: E501

    OpenAPI spec version: 0.22.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from killbill.api_client import ApiClient


class AdminApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_queue_entries(self, **kwargs):  # noqa: E501
        """Get queues entries  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_queue_entries(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str account_id:
        :param str queue_name:
        :param str service_name:
        :param bool with_history:
        :param str min_date:
        :param str max_date:
        :param bool with_in_processing:
        :param bool with_bus_events:
        :param bool with_notifications:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_queue_entries_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_queue_entries_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_queue_entries_with_http_info(self, **kwargs):  # noqa: E501
        """Get queues entries  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_queue_entries_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str account_id:
        :param str queue_name:
        :param str service_name:
        :param bool with_history:
        :param str min_date:
        :param str max_date:
        :param bool with_in_processing:
        :param bool with_bus_events:
        :param bool with_notifications:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['account_id', 'queue_name', 'service_name', 'with_history', 'min_date', 'max_date', 'with_in_processing', 'with_bus_events', 'with_notifications']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_queue_entries" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'account_id' in params:
            query_params.append(('accountId', params['account_id']))  # noqa: E501
        if 'queue_name' in params:
            query_params.append(('queueName', params['queue_name']))  # noqa: E501
        if 'service_name' in params:
            query_params.append(('serviceName', params['service_name']))  # noqa: E501
        if 'with_history' in params:
            query_params.append(('withHistory', params['with_history']))  # noqa: E501
        if 'min_date' in params:
            query_params.append(('minDate', params['min_date']))  # noqa: E501
        if 'max_date' in params:
            query_params.append(('maxDate', params['max_date']))  # noqa: E501
        if 'with_in_processing' in params:
            query_params.append(('withInProcessing', params['with_in_processing']))  # noqa: E501
        if 'with_bus_events' in params:
            query_params.append(('withBusEvents', params['with_bus_events']))  # noqa: E501
        if 'with_notifications' in params:
            query_params.append(('withNotifications', params['with_notifications']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['Killbill Api Key', 'Killbill Api Secret', 'basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/1.0/kb/admin/queues', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def invalidates_cache(self, **kwargs):  # noqa: E501
        """Invalidates the given Cache if specified, otherwise invalidates all caches  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.invalidates_cache(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cache_name:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.invalidates_cache_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.invalidates_cache_with_http_info(**kwargs)  # noqa: E501
            return data

    def invalidates_cache_with_http_info(self, **kwargs):  # noqa: E501
        """Invalidates the given Cache if specified, otherwise invalidates all caches  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.invalidates_cache_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cache_name:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cache_name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method invalidates_cache" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'cache_name' in params:
            query_params.append(('cacheName', params['cache_name']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['Killbill Api Key', 'Killbill Api Secret', 'basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/1.0/kb/admin/cache', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def invalidates_cache_by_account(self, account_id, **kwargs):  # noqa: E501
        """Invalidates Caches per account level  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.invalidates_cache_by_account(account_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str account_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.invalidates_cache_by_account_with_http_info(account_id, **kwargs)  # noqa: E501
        else:
            (data) = self.invalidates_cache_by_account_with_http_info(account_id, **kwargs)  # noqa: E501
            return data

    def invalidates_cache_by_account_with_http_info(self, account_id, **kwargs):  # noqa: E501
        """Invalidates Caches per account level  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.invalidates_cache_by_account_with_http_info(account_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str account_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['account_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method invalidates_cache_by_account" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'account_id' is set
        if ('account_id' not in params or
                params['account_id'] is None):
            raise ValueError("Missing the required parameter `account_id` when calling `invalidates_cache_by_account`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'account_id' in params:
            path_params['accountId'] = params['account_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['Killbill Api Key', 'Killbill Api Secret', 'basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/1.0/kb/admin/cache/accounts/{accountId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def invalidates_cache_by_tenant(self, **kwargs):  # noqa: E501
        """Invalidates Caches per tenant level  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.invalidates_cache_by_tenant(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.invalidates_cache_by_tenant_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.invalidates_cache_by_tenant_with_http_info(**kwargs)  # noqa: E501
            return data

    def invalidates_cache_by_tenant_with_http_info(self, **kwargs):  # noqa: E501
        """Invalidates Caches per tenant level  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.invalidates_cache_by_tenant_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method invalidates_cache_by_tenant" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['Killbill Api Key', 'Killbill Api Secret', 'basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/1.0/kb/admin/cache/tenants', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def put_in_rotation(self, **kwargs):  # noqa: E501
        """Put the host back into rotation  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_in_rotation(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.put_in_rotation_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.put_in_rotation_with_http_info(**kwargs)  # noqa: E501
            return data

    def put_in_rotation_with_http_info(self, **kwargs):  # noqa: E501
        """Put the host back into rotation  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_in_rotation_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_in_rotation" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['Killbill Api Key', 'Killbill Api Secret', 'basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/1.0/kb/admin/healthcheck', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def put_out_of_rotation(self, **kwargs):  # noqa: E501
        """Put the host out of rotation  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_out_of_rotation(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.put_out_of_rotation_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.put_out_of_rotation_with_http_info(**kwargs)  # noqa: E501
            return data

    def put_out_of_rotation_with_http_info(self, **kwargs):  # noqa: E501
        """Put the host out of rotation  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_out_of_rotation_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_out_of_rotation" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['Killbill Api Key', 'Killbill Api Secret', 'basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/1.0/kb/admin/healthcheck', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def trigger_invoice_generation_for_parked_accounts(self, x_killbill_created_by, **kwargs):  # noqa: E501
        """Trigger an invoice generation for all parked accounts  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.trigger_invoice_generation_for_parked_accounts(x_killbill_created_by, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_killbill_created_by: (required)
        :param int offset:
        :param int limit:
        :param str x_killbill_reason:
        :param str x_killbill_comment:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.trigger_invoice_generation_for_parked_accounts_with_http_info(x_killbill_created_by, **kwargs)  # noqa: E501
        else:
            (data) = self.trigger_invoice_generation_for_parked_accounts_with_http_info(x_killbill_created_by, **kwargs)  # noqa: E501
            return data

    def trigger_invoice_generation_for_parked_accounts_with_http_info(self, x_killbill_created_by, **kwargs):  # noqa: E501
        """Trigger an invoice generation for all parked accounts  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.trigger_invoice_generation_for_parked_accounts_with_http_info(x_killbill_created_by, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_killbill_created_by: (required)
        :param int offset:
        :param int limit:
        :param str x_killbill_reason:
        :param str x_killbill_comment:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['x_killbill_created_by', 'offset', 'limit', 'x_killbill_reason', 'x_killbill_comment']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method trigger_invoice_generation_for_parked_accounts" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'x_killbill_created_by' is set
        if ('x_killbill_created_by' not in params or
                params['x_killbill_created_by'] is None):
            raise ValueError("Missing the required parameter `x_killbill_created_by` when calling `trigger_invoice_generation_for_parked_accounts`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'offset' in params:
            query_params.append(('offset', params['offset']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501

        header_params = {}
        if 'x_killbill_created_by' in params:
            header_params['X-Killbill-CreatedBy'] = params['x_killbill_created_by']  # noqa: E501
        if 'x_killbill_reason' in params:
            header_params['X-Killbill-Reason'] = params['x_killbill_reason']  # noqa: E501
        if 'x_killbill_comment' in params:
            header_params['X-Killbill-Comment'] = params['x_killbill_comment']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['Killbill Api Key', 'Killbill Api Secret', 'basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/1.0/kb/admin/invoices', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_payment_transaction_state(self, body, x_killbill_created_by, payment_id, payment_transaction_id, **kwargs):  # noqa: E501
        """Update existing paymentTransaction and associated payment state  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_payment_transaction_state(body, x_killbill_created_by, payment_id, payment_transaction_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AdminPayment body: (required)
        :param str x_killbill_created_by: (required)
        :param str payment_id: (required)
        :param str payment_transaction_id: (required)
        :param str x_killbill_reason:
        :param str x_killbill_comment:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_payment_transaction_state_with_http_info(body, x_killbill_created_by, payment_id, payment_transaction_id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_payment_transaction_state_with_http_info(body, x_killbill_created_by, payment_id, payment_transaction_id, **kwargs)  # noqa: E501
            return data

    def update_payment_transaction_state_with_http_info(self, body, x_killbill_created_by, payment_id, payment_transaction_id, **kwargs):  # noqa: E501
        """Update existing paymentTransaction and associated payment state  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_payment_transaction_state_with_http_info(body, x_killbill_created_by, payment_id, payment_transaction_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AdminPayment body: (required)
        :param str x_killbill_created_by: (required)
        :param str payment_id: (required)
        :param str payment_transaction_id: (required)
        :param str x_killbill_reason:
        :param str x_killbill_comment:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'x_killbill_created_by', 'payment_id', 'payment_transaction_id', 'x_killbill_reason', 'x_killbill_comment']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_payment_transaction_state" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `update_payment_transaction_state`")  # noqa: E501
        # verify the required parameter 'x_killbill_created_by' is set
        if ('x_killbill_created_by' not in params or
                params['x_killbill_created_by'] is None):
            raise ValueError("Missing the required parameter `x_killbill_created_by` when calling `update_payment_transaction_state`")  # noqa: E501
        # verify the required parameter 'payment_id' is set
        if ('payment_id' not in params or
                params['payment_id'] is None):
            raise ValueError("Missing the required parameter `payment_id` when calling `update_payment_transaction_state`")  # noqa: E501
        # verify the required parameter 'payment_transaction_id' is set
        if ('payment_transaction_id' not in params or
                params['payment_transaction_id'] is None):
            raise ValueError("Missing the required parameter `payment_transaction_id` when calling `update_payment_transaction_state`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'payment_id' in params:
            path_params['paymentId'] = params['payment_id']  # noqa: E501
        if 'payment_transaction_id' in params:
            path_params['paymentTransactionId'] = params['payment_transaction_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_killbill_created_by' in params:
            header_params['X-Killbill-CreatedBy'] = params['x_killbill_created_by']  # noqa: E501
        if 'x_killbill_reason' in params:
            header_params['X-Killbill-Reason'] = params['x_killbill_reason']  # noqa: E501
        if 'x_killbill_comment' in params:
            header_params['X-Killbill-Comment'] = params['x_killbill_comment']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Killbill Api Key', 'Killbill Api Secret', 'basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/1.0/kb/admin/payments/{paymentId}/transactions/{paymentTransactionId}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Kill Bill

    Kill Bill is an open-source billing and payments platform  # noqa: E501

    OpenAPI spec version: 0.22.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class PaymentMethodPluginDetail(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'external_payment_method_id': 'str',
        'is_default_payment_method': 'bool',
        'properties': 'list[PluginProperty]'
    }

    attribute_map = {
        'external_payment_method_id': 'externalPaymentMethodId',
        'is_default_payment_method': 'isDefaultPaymentMethod',
        'properties': 'properties'
    }

    def __init__(self, external_payment_method_id=None, is_default_payment_method=None, properties=None):  # noqa: E501
        """PaymentMethodPluginDetail - a model defined in Swagger"""  # noqa: E501
        self._external_payment_method_id = None
        self._is_default_payment_method = None
        self._properties = None
        self.discriminator = None
        if external_payment_method_id is not None:
            self.external_payment_method_id = external_payment_method_id
        if is_default_payment_method is not None:
            self.is_default_payment_method = is_default_payment_method
        if properties is not None:
            self.properties = properties

    @property
    def external_payment_method_id(self):
        """Gets the external_payment_method_id of this PaymentMethodPluginDetail.  # noqa: E501


        :return: The external_payment_method_id of this PaymentMethodPluginDetail.  # noqa: E501
        :rtype: str
        """
        return self._external_payment_method_id

    @external_payment_method_id.setter
    def external_payment_method_id(self, external_payment_method_id):
        """Sets the external_payment_method_id of this PaymentMethodPluginDetail.


        :param external_payment_method_id: The external_payment_method_id of this PaymentMethodPluginDetail.  # noqa: E501
        :type: str
        """

        self._external_payment_method_id = external_payment_method_id

    @property
    def is_default_payment_method(self):
        """Gets the is_default_payment_method of this PaymentMethodPluginDetail.  # noqa: E501


        :return: The is_default_payment_method of this PaymentMethodPluginDetail.  # noqa: E501
        :rtype: bool
        """
        return self._is_default_payment_method

    @is_default_payment_method.setter
    def is_default_payment_method(self, is_default_payment_method):
        """Sets the is_default_payment_method of this PaymentMethodPluginDetail.


        :param is_default_payment_method: The is_default_payment_method of this PaymentMethodPluginDetail.  # noqa: E501
        :type: bool
        """

        self._is_default_payment_method = is_default_payment_method

    @property
    def properties(self):
        """Gets the properties of this PaymentMethodPluginDetail.  # noqa: E501


        :return: The properties of this PaymentMethodPluginDetail.  # noqa: E501
        :rtype: list[PluginProperty]
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """Sets the properties of this PaymentMethodPluginDetail.


        :param properties: The properties of this PaymentMethodPluginDetail.  # noqa: E501
        :type: list[PluginProperty]
        """

        self._properties = properties

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PaymentMethodPluginDetail, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PaymentMethodPluginDetail):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Kill Bill

    Kill Bill is an open-source billing and payments platform  # noqa: E501

    OpenAPI spec version: 0.22.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class BlockPrice(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'unit_name': 'str',
        'size': 'float',
        'price': 'float',
        'max': 'float'
    }

    attribute_map = {
        'unit_name': 'unitName',
        'size': 'size',
        'price': 'price',
        'max': 'max'
    }

    def __init__(self, unit_name=None, size=None, price=None, max=None):  # noqa: E501
        """BlockPrice - a model defined in Swagger"""  # noqa: E501
        self._unit_name = None
        self._size = None
        self._price = None
        self._max = None
        self.discriminator = None
        if unit_name is not None:
            self.unit_name = unit_name
        if size is not None:
            self.size = size
        if price is not None:
            self.price = price
        if max is not None:
            self.max = max

    @property
    def unit_name(self):
        """Gets the unit_name of this BlockPrice.  # noqa: E501


        :return: The unit_name of this BlockPrice.  # noqa: E501
        :rtype: str
        """
        return self._unit_name

    @unit_name.setter
    def unit_name(self, unit_name):
        """Sets the unit_name of this BlockPrice.


        :param unit_name: The unit_name of this BlockPrice.  # noqa: E501
        :type: str
        """

        self._unit_name = unit_name

    @property
    def size(self):
        """Gets the size of this BlockPrice.  # noqa: E501


        :return: The size of this BlockPrice.  # noqa: E501
        :rtype: float
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this BlockPrice.


        :param size: The size of this BlockPrice.  # noqa: E501
        :type: float
        """

        self._size = size

    @property
    def price(self):
        """Gets the price of this BlockPrice.  # noqa: E501


        :return: The price of this BlockPrice.  # noqa: E501
        :rtype: float
        """
        return self._price

    @price.setter
    def price(self, price):
        """Sets the price of this BlockPrice.


        :param price: The price of this BlockPrice.  # noqa: E501
        :type: float
        """

        self._price = price

    @property
    def max(self):
        """Gets the max of this BlockPrice.  # noqa: E501


        :return: The max of this BlockPrice.  # noqa: E501
        :rtype: float
        """
        return self._max

    @max.setter
    def max(self, max):
        """Sets the max of this BlockPrice.


        :param max: The max of this BlockPrice.  # noqa: E501
        :type: float
        """

        self._max = max

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(BlockPrice, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BlockPrice):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Kill Bill

    Kill Bill is an open-source billing and payments platform  # noqa: E501

    OpenAPI spec version: 0.22.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class BundleTimeline(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'account_id': 'str',
        'bundle_id': 'str',
        'external_key': 'str',
        'events': 'list[EventSubscription]',
        'audit_logs': 'list[AuditLog]'
    }

    attribute_map = {
        'account_id': 'accountId',
        'bundle_id': 'bundleId',
        'external_key': 'externalKey',
        'events': 'events',
        'audit_logs': 'auditLogs'
    }

    def __init__(self, account_id=None, bundle_id=None, external_key=None, events=None, audit_logs=None):  # noqa: E501
        """BundleTimeline - a model defined in Swagger"""  # noqa: E501
        self._account_id = None
        self._bundle_id = None
        self._external_key = None
        self._events = None
        self._audit_logs = None
        self.discriminator = None
        if account_id is not None:
            self.account_id = account_id
        if bundle_id is not None:
            self.bundle_id = bundle_id
        if external_key is not None:
            self.external_key = external_key
        if events is not None:
            self.events = events
        if audit_logs is not None:
            self.audit_logs = audit_logs

    @property
    def account_id(self):
        """Gets the account_id of this BundleTimeline.  # noqa: E501


        :return: The account_id of this BundleTimeline.  # noqa: E501
        :rtype: str
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this BundleTimeline.


        :param account_id: The account_id of this BundleTimeline.  # noqa: E501
        :type: str
        """

        self._account_id = account_id

    @property
    def bundle_id(self):
        """Gets the bundle_id of this BundleTimeline.  # noqa: E501


        :return: The bundle_id of this BundleTimeline.  # noqa: E501
        :rtype: str
        """
        return self._bundle_id

    @bundle_id.setter
    def bundle_id(self, bundle_id):
        """Sets the bundle_id of this BundleTimeline.


        :param bundle_id: The bundle_id of this BundleTimeline.  # noqa: E501
        :type: str
        """

        self._bundle_id = bundle_id

    @property
    def external_key(self):
        """Gets the external_key of this BundleTimeline.  # noqa: E501


        :return: The external_key of this BundleTimeline.  # noqa: E501
        :rtype: str
        """
        return self._external_key

    @external_key.setter
    def external_key(self, external_key):
        """Sets the external_key of this BundleTimeline.


        :param external_key: The external_key of this BundleTimeline.  # noqa: E501
        :type: str
        """

        self._external_key = external_key

    @property
    def events(self):
        """Gets the events of this BundleTimeline.  # noqa: E501


        :return: The events of this BundleTimeline.  # noqa: E501
        :rtype: list[EventSubscription]
        """
        return self._events

    @events.setter
    def events(self, events):
        """Sets the events of this BundleTimeline.


        :param events: The events of this BundleTimeline.  # noqa: E501
        :type: list[EventSubscription]
        """

        self._events = events

    @property
    def audit_logs(self):
        """Gets the audit_logs of this BundleTimeline.  # noqa: E501


        :return: The audit_logs of this BundleTimeline.  # noqa: E501
        :rtype: list[AuditLog]
        """
        return self._audit_logs

    @audit_logs.setter
    def audit_logs(self, audit_logs):
        """Sets the audit_logs of this BundleTimeline.


        :param audit_logs: The audit_logs of this BundleTimeline.  # noqa: E501
        :type: list[AuditLog]
        """

        self._audit_logs = audit_logs

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(BundleTimeline, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BundleTimeline):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Kill Bill

    Kill Bill is an open-source billing and payments platform  # noqa: E501

    OpenAPI spec version: 0.22.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class PlanDetail(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'product': 'str',
        'plan': 'str',
        'price_list': 'str',
        'final_phase_billing_period': 'str',
        'final_phase_recurring_price': 'list[Price]'
    }

    attribute_map = {
        'product': 'product',
        'plan': 'plan',
        'price_list': 'priceList',
        'final_phase_billing_period': 'finalPhaseBillingPeriod',
        'final_phase_recurring_price': 'finalPhaseRecurringPrice'
    }

    def __init__(self, product=None, plan=None, price_list=None, final_phase_billing_period=None, final_phase_recurring_price=None):  # noqa: E501
        """PlanDetail - a model defined in Swagger"""  # noqa: E501
        self._product = None
        self._plan = None
        self._price_list = None
        self._final_phase_billing_period = None
        self._final_phase_recurring_price = None
        self.discriminator = None
        if product is not None:
            self.product = product
        if plan is not None:
            self.plan = plan
        if price_list is not None:
            self.price_list = price_list
        if final_phase_billing_period is not None:
            self.final_phase_billing_period = final_phase_billing_period
        if final_phase_recurring_price is not None:
            self.final_phase_recurring_price = final_phase_recurring_price

    @property
    def product(self):
        """Gets the product of this PlanDetail.  # noqa: E501


        :return: The product of this PlanDetail.  # noqa: E501
        :rtype: str
        """
        return self._product

    @product.setter
    def product(self, product):
        """Sets the product of this PlanDetail.


        :param product: The product of this PlanDetail.  # noqa: E501
        :type: str
        """

        self._product = product

    @property
    def plan(self):
        """Gets the plan of this PlanDetail.  # noqa: E501


        :return: The plan of this PlanDetail.  # noqa: E501
        :rtype: str
        """
        return self._plan

    @plan.setter
    def plan(self, plan):
        """Sets the plan of this PlanDetail.


        :param plan: The plan of this PlanDetail.  # noqa: E501
        :type: str
        """

        self._plan = plan

    @property
    def price_list(self):
        """Gets the price_list of this PlanDetail.  # noqa: E501


        :return: The price_list of this PlanDetail.  # noqa: E501
        :rtype: str
        """
        return self._price_list

    @price_list.setter
    def price_list(self, price_list):
        """Sets the price_list of this PlanDetail.


        :param price_list: The price_list of this PlanDetail.  # noqa: E501
        :type: str
        """

        self._price_list = price_list

    @property
    def final_phase_billing_period(self):
        """Gets the final_phase_billing_period of this PlanDetail.  # noqa: E501


        :return: The final_phase_billing_period of this PlanDetail.  # noqa: E501
        :rtype: str
        """
        return self._final_phase_billing_period

    @final_phase_billing_period.setter
    def final_phase_billing_period(self, final_phase_billing_period):
        """Sets the final_phase_billing_period of this PlanDetail.


        :param final_phase_billing_period: The final_phase_billing_period of this PlanDetail.  # noqa: E501
        :type: str
        """
        allowed_values = ["DAILY", "WEEKLY", "BIWEEKLY", "THIRTY_DAYS", "SIXTY_DAYS", "NINETY_DAYS", "MONTHLY", "BIMESTRIAL", "QUARTERLY", "TRIANNUAL", "BIANNUAL", "ANNUAL", "BIENNIAL", "NO_BILLING_PERIOD"]  # noqa: E501
        if final_phase_billing_period not in allowed_values:
            raise ValueError(
                "Invalid value for `final_phase_billing_period` ({0}), must be one of {1}"  # noqa: E501
                .format(final_phase_billing_period, allowed_values)
            )

        self._final_phase_billing_period = final_phase_billing_period

    @property
    def final_phase_recurring_price(self):
        """Gets the final_phase_recurring_price of this PlanDetail.  # noqa: E501


        :return: The final_phase_recurring_price of this PlanDetail.  # noqa: E501
        :rtype: list[Price]
        """
        return self._final_phase_recurring_price

    @final_phase_recurring_price.setter
    def final_phase_recurring_price(self, final_phase_recurring_price):
        """Sets the final_phase_recurring_price of this PlanDetail.


        :param final_phase_recurring_price: The final_phase_recurring_price of this PlanDetail.  # noqa: E501
        :type: list[Price]
        """

        self._final_phase_recurring_price = final_phase_recurring_price

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PlanDetail, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PlanDetail):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Kill Bill

    Kill Bill is an open-source billing and payments platform  # noqa: E501

    OpenAPI spec version: 0.22.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class SimplePlan(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'plan_id': 'str',
        'product_name': 'str',
        'product_category': 'str',
        'currency': 'str',
        'amount': 'float',
        'billing_period': 'str',
        'trial_length': 'int',
        'trial_time_unit': 'str',
        'available_base_products': 'list[str]'
    }

    attribute_map = {
        'plan_id': 'planId',
        'product_name': 'productName',
        'product_category': 'productCategory',
        'currency': 'currency',
        'amount': 'amount',
        'billing_period': 'billingPeriod',
        'trial_length': 'trialLength',
        'trial_time_unit': 'trialTimeUnit',
        'available_base_products': 'availableBaseProducts'
    }

    def __init__(self, plan_id=None, product_name=None, product_category=None, currency=None, amount=None, billing_period=None, trial_length=None, trial_time_unit=None, available_base_products=None):  # noqa: E501
        """SimplePlan - a model defined in Swagger"""  # noqa: E501
        self._plan_id = None
        self._product_name = None
        self._product_category = None
        self._currency = None
        self._amount = None
        self._billing_period = None
        self._trial_length = None
        self._trial_time_unit = None
        self._available_base_products = None
        self.discriminator = None
        if plan_id is not None:
            self.plan_id = plan_id
        if product_name is not None:
            self.product_name = product_name
        if product_category is not None:
            self.product_category = product_category
        if currency is not None:
            self.currency = currency
        if amount is not None:
            self.amount = amount
        if billing_period is not None:
            self.billing_period = billing_period
        if trial_length is not None:
            self.trial_length = trial_length
        if trial_time_unit is not None:
            self.trial_time_unit = trial_time_unit
        if available_base_products is not None:
            self.available_base_products = available_base_products

    @property
    def plan_id(self):
        """Gets the plan_id of this SimplePlan.  # noqa: E501


        :return: The plan_id of this SimplePlan.  # noqa: E501
        :rtype: str
        """
        return self._plan_id

    @plan_id.setter
    def plan_id(self, plan_id):
        """Sets the plan_id of this SimplePlan.


        :param plan_id: The plan_id of this SimplePlan.  # noqa: E501
        :type: str
        """

        self._plan_id = plan_id

    @property
    def product_name(self):
        """Gets the product_name of this SimplePlan.  # noqa: E501


        :return: The product_name of this SimplePlan.  # noqa: E501
        :rtype: str
        """
        return self._product_name

    @product_name.setter
    def product_name(self, product_name):
        """Sets the product_name of this SimplePlan.


        :param product_name: The product_name of this SimplePlan.  # noqa: E501
        :type: str
        """

        self._product_name = product_name

    @property
    def product_category(self):
        """Gets the product_category of this SimplePlan.  # noqa: E501


        :return: The product_category of this SimplePlan.  # noqa: E501
        :rtype: str
        """
        return self._product_category

    @product_category.setter
    def product_category(self, product_category):
        """Sets the product_category of this SimplePlan.


        :param product_category: The product_category of this SimplePlan.  # noqa: E501
        :type: str
        """
        allowed_values = ["BASE", "ADD_ON", "STANDALONE"]  # noqa: E501
        if product_category not in allowed_values:
            raise ValueError(
                "Invalid value for `product_category` ({0}), must be one of {1}"  # noqa: E501
                .format(product_category, allowed_values)
            )

        self._product_category = product_category

    @property
    def currency(self):
        """Gets the currency of this SimplePlan.  # noqa: E501


        :return: The currency of this SimplePlan.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this SimplePlan.


        :param currency: The currency of this SimplePlan.  # noqa: E501
        :type: str
        """
        allowed_values = ["AED", "AFN", "ALL", "AMD", "ANG", "AOA", "ARS", "AUD", "AWG", "AZN", "BAM", "BBD", "BDT", "BGN", "BHD", "BIF", "BMD", "BND", "BOB", "BRL", "BSD", "BTN", "BWP", "BYR", "BZD", "CAD", "CDF", "CHF", "CLP", "CNY", "COP", "CRC", "CUC", "CUP", "CVE", "CZK", "DJF", "DKK", "DOP", "DZD", "EGP", "ERN", "ETB", "EUR", "FJD", "FKP", "GBP", "GEL", "GGP", "GHS", "GIP", "GMD", "GNF", "GTQ", "GYD", "HKD", "HNL", "HRK", "HTG", "HUF", "IDR", "ILS", "IMP", "INR", "IQD", "IRR", "ISK", "JEP", "JMD", "JOD", "JPY", "KES", "KGS", "KHR", "KMF", "KPW", "KRW", "KWD", "KYD", "KZT", "LAK", "LBP", "LKR", "LRD", "LSL", "LTL", "LVL", "LYD", "MAD", "MDL", "MGA", "MKD", "MMK", "MNT", "MOP", "MRO", "MUR", "MVR", "MWK", "MXN", "MYR", "MZN", "NAD", "NGN", "NIO", "NOK", "NPR", "NZD", "OMR", "PAB", "PEN", "PGK", "PHP", "PKR", "PLN", "PYG", "QAR", "RON", "RSD", "RUB", "RWF", "SAR", "SBD", "SCR", "SDG", "SEK", "SGD", "SHP", "SLL", "SOS", "SPL", "SRD", "STD", "SVC", "SYP", "SZL", "THB", "TJS", "TMT", "TND", "TOP", "TRY", "TTD", "TVD", "TWD", "TZS", "UAH", "UGX", "USD", "UYU", "UZS", "VEF", "VND", "VUV", "WST", "XAF", "XCD", "XDR", "XOF", "XPF", "YER", "ZAR", "ZMW", "ZWD", "BTC"]  # noqa: E501
        if currency not in allowed_values:
            raise ValueError(
                "Invalid value for `currency` ({0}), must be one of {1}"  # noqa: E501
                .format(currency, allowed_values)
            )

        self._currency = currency

    @property
    def amount(self):
        """Gets the amount of this SimplePlan.  # noqa: E501


        :return: The amount of this SimplePlan.  # noqa: E501
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this SimplePlan.


        :param amount: The amount of this SimplePlan.  # noqa: E501
        :type: float
        """

        self._amount = amount

    @property
    def billing_period(self):
        """Gets the billing_period of this SimplePlan.  # noqa: E501


        :return: The billing_period of this SimplePlan.  # noqa: E501
        :rtype: str
        """
        return self._billing_period

    @billing_period.setter
    def billing_period(self, billing_period):
        """Sets the billing_period of this SimplePlan.


        :param billing_period: The billing_period of this SimplePlan.  # noqa: E501
        :type: str
        """
        allowed_values = ["DAILY", "WEEKLY", "BIWEEKLY", "THIRTY_DAYS", "SIXTY_DAYS", "NINETY_DAYS", "MONTHLY", "BIMESTRIAL", "QUARTERLY", "TRIANNUAL", "BIANNUAL", "ANNUAL", "BIENNIAL", "NO_BILLING_PERIOD"]  # noqa: E501
        if billing_period not in allowed_values:
            raise ValueError(
                "Invalid value for `billing_period` ({0}), must be one of {1}"  # noqa: E501
                .format(billing_period, allowed_values)
            )

        self._billing_period = billing_period

    @property
    def trial_length(self):
        """Gets the trial_length of this SimplePlan.  # noqa: E501


        :return: The trial_length of this SimplePlan.  # noqa: E501
        :rtype: int
        """
        return self._trial_length

    @trial_length.setter
    def trial_length(self, trial_length):
        """Sets the trial_length of this SimplePlan.


        :param trial_length: The trial_length of this SimplePlan.  # noqa: E501
        :type: int
        """

        self._trial_length = trial_length

    @property
    def trial_time_unit(self):
        """Gets the trial_time_unit of this SimplePlan.  # noqa: E501


        :return: The trial_time_unit of this SimplePlan.  # noqa: E501
        :rtype: str
        """
        return self._trial_time_unit

    @trial_time_unit.setter
    def trial_time_unit(self, trial_time_unit):
        """Sets the trial_time_unit of this SimplePlan.


        :param trial_time_unit: The trial_time_unit of this SimplePlan.  # noqa: E501
        :type: str
        """
        allowed_values = ["DAYS", "WEEKS", "MONTHS", "YEARS", "UNLIMITED"]  # noqa: E501
        if trial_time_unit not in allowed_values:
            raise ValueError(
                "Invalid value for `trial_time_unit` ({0}), must be one of {1}"  # noqa: E501
                .format(trial_time_unit, allowed_values)
            )

        self._trial_time_unit = trial_time_unit

    @property
    def available_base_products(self):
        """Gets the available_base_products of this SimplePlan.  # noqa: E501


        :return: The available_base_products of this SimplePlan.  # noqa: E501
        :rtype: list[str]
        """
        return self._available_base_products

    @available_base_products.setter
    def available_base_products(self, available_base_products):
        """Sets the available_base_products of this SimplePlan.


        :param available_base_products: The available_base_products of this SimplePlan.  # noqa: E501
        :type: list[str]
        """

        self._available_base_products = available_base_products

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SimplePlan, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SimplePlan):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Kill Bill

    Kill Bill is an open-source billing and payments platform  # noqa: E501

    OpenAPI spec version: 0.22.22-SNAPSHOT
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import killbill
from killbill.api.invoice_payment_api import InvoicePaymentApi  # noqa: E501
from killbill.rest import ApiException


class TestInvoicePaymentApi(unittest.TestCase):
    """InvoicePaymentApi unit test stubs"""

    def setUp(self):
        self.api = killbill.api.invoice_payment_api.InvoicePaymentApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_complete_invoice_payment_transaction(self):
        """Test case for complete_invoice_payment_transaction

        Complete an existing transaction  # noqa: E501
        """
        pass

    def test_create_chargeback(self):
        """Test case for create_chargeback

        Record a chargeback  # noqa: E501
        """
        pass

    def test_create_chargeback_reversal(self):
        """Test case for create_chargeback_reversal

        Record a chargebackReversal  # noqa: E501
        """
        pass

    def test_create_invoice_payment_custom_fields(self):
        """Test case for create_invoice_payment_custom_fields

        Add custom fields to payment  # noqa: E501
        """
        pass

    def test_create_invoice_payment_tags(self):
        """Test case for create_invoice_payment_tags

        Add tags to payment  # noqa: E501
        """
        pass

    def test_create_refund_with_adjustments(self):
        """Test case for create_refund_with_adjustments

        Refund a payment, and adjust the invoice if needed  # noqa: E501
        """
        pass

    def test_delete_invoice_payment_custom_fields(self):
        """Test case for delete_invoice_payment_custom_fields

        Remove custom fields from payment  # noqa: E501
        """
        pass

    def test_delete_invoice_payment_tags(self):
        """Test case for delete_invoice_payment_tags

        Remove tags from payment  # noqa: E501
        """
        pass

    def test_get_invoice_payment(self):
        """Test case for get_invoice_payment

        Retrieve a payment by id  # noqa: E501
        """
        pass

    def test_get_invoice_payment_audit_logs_with_history(self):
        """Test case for get_invoice_payment_audit_logs_with_history

        Retrieve invoice payment audit logs with history by id  # noqa: E501
        """
        pass

    def test_get_invoice_payment_custom_fields(self):
        """Test case for get_invoice_payment_custom_fields

        Retrieve payment custom fields  # noqa: E501
        """
        pass

    def test_get_invoice_payment_tags(self):
        """Test case for get_invoice_payment_tags

        Retrieve payment tags  # noqa: E501
        """
        pass

    def test_modify_invoice_payment_custom_fields(self):
        """Test case for modify_invoice_payment_custom_fields

        Modify custom fields to payment  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Kill Bill

    Kill Bill is an open-source billing and payments platform  # noqa: E501

    OpenAPI spec version: 0.22.22-SNAPSHOT
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import killbill
from killbill.api.invoice_api import InvoiceApi  # noqa: E501
from killbill.rest import ApiException


class TestInvoiceApi(unittest.TestCase):
    """InvoiceApi unit test stubs"""

    def setUp(self):
        self.api = killbill.api.invoice_api.InvoiceApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_adjust_invoice_item(self):
        """Test case for adjust_invoice_item

        Adjust an invoice item  # noqa: E501
        """
        pass

    def test_commit_invoice(self):
        """Test case for commit_invoice

        Perform the invoice status transition from DRAFT to COMMITTED  # noqa: E501
        """
        pass

    def test_create_external_charges(self):
        """Test case for create_external_charges

        Create external charge(s)  # noqa: E501
        """
        pass

    def test_create_future_invoice(self):
        """Test case for create_future_invoice

        Trigger an invoice generation  # noqa: E501
        """
        pass

    def test_create_instant_payment(self):
        """Test case for create_instant_payment

        Trigger a payment for invoice  # noqa: E501
        """
        pass

    def test_create_invoice_custom_fields(self):
        """Test case for create_invoice_custom_fields

        Add custom fields to invoice  # noqa: E501
        """
        pass

    def test_create_invoice_tags(self):
        """Test case for create_invoice_tags

        Add tags to invoice  # noqa: E501
        """
        pass

    def test_create_migration_invoice(self):
        """Test case for create_migration_invoice

        Create a migration invoice  # noqa: E501
        """
        pass

    def test_create_tax_items(self):
        """Test case for create_tax_items

        Create tax items  # noqa: E501
        """
        pass

    def test_delete_cba(self):
        """Test case for delete_cba

        Delete a CBA item  # noqa: E501
        """
        pass

    def test_delete_invoice_custom_fields(self):
        """Test case for delete_invoice_custom_fields

        Remove custom fields from invoice  # noqa: E501
        """
        pass

    def test_delete_invoice_tags(self):
        """Test case for delete_invoice_tags

        Remove tags from invoice  # noqa: E501
        """
        pass

    def test_generate_dry_run_invoice(self):
        """Test case for generate_dry_run_invoice

        Generate a dryRun invoice  # noqa: E501
        """
        pass

    def test_get_catalog_translation(self):
        """Test case for get_catalog_translation

        Retrieves the catalog translation for the tenant  # noqa: E501
        """
        pass

    def test_get_invoice(self):
        """Test case for get_invoice

        Retrieve an invoice by id  # noqa: E501
        """
        pass

    def test_get_invoice_as_html(self):
        """Test case for get_invoice_as_html

        Render an invoice as HTML  # noqa: E501
        """
        pass

    def test_get_invoice_audit_logs_with_history(self):
        """Test case for get_invoice_audit_logs_with_history

        Retrieve invoice audit logs with history by id  # noqa: E501
        """
        pass

    def test_get_invoice_by_item_id(self):
        """Test case for get_invoice_by_item_id

        Retrieve an invoice by invoice item id  # noqa: E501
        """
        pass

    def test_get_invoice_by_number(self):
        """Test case for get_invoice_by_number

        Retrieve an invoice by number  # noqa: E501
        """
        pass

    def test_get_invoice_custom_fields(self):
        """Test case for get_invoice_custom_fields

        Retrieve invoice custom fields  # noqa: E501
        """
        pass

    def test_get_invoice_mp_template(self):
        """Test case for get_invoice_mp_template

        Retrieves the manualPay invoice template for the tenant  # noqa: E501
        """
        pass

    def test_get_invoice_tags(self):
        """Test case for get_invoice_tags

        Retrieve invoice tags  # noqa: E501
        """
        pass

    def test_get_invoice_template(self):
        """Test case for get_invoice_template

        Retrieves the invoice template for the tenant  # noqa: E501
        """
        pass

    def test_get_invoice_translation(self):
        """Test case for get_invoice_translation

        Retrieves the invoice translation for the tenant  # noqa: E501
        """
        pass

    def test_get_invoices(self):
        """Test case for get_invoices

        List invoices  # noqa: E501
        """
        pass

    def test_get_payments_for_invoice(self):
        """Test case for get_payments_for_invoice

        Retrieve payments associated with an invoice  # noqa: E501
        """
        pass

    def test_modify_invoice_custom_fields(self):
        """Test case for modify_invoice_custom_fields

        Modify custom fields to invoice  # noqa: E501
        """
        pass

    def test_search_invoices(self):
        """Test case for search_invoices

        Search invoices  # noqa: E501
        """
        pass

    def test_upload_catalog_translation(self):
        """Test case for upload_catalog_translation

        Upload the catalog translation for the tenant  # noqa: E501
        """
        pass

    def test_upload_invoice_mp_template(self):
        """Test case for upload_invoice_mp_template

        Upload the manualPay invoice template for the tenant  # noqa: E501
        """
        pass

    def test_upload_invoice_template(self):
        """Test case for upload_invoice_template

        Upload the invoice template for the tenant  # noqa: E501
        """
        pass

    def test_upload_invoice_translation(self):
        """Test case for upload_invoice_translation

        Upload the invoice translation for the tenant  # noqa: E501
        """
        pass

    def test_void_invoice(self):
        """Test case for void_invoice

        Perform the action of voiding an invoice  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Kill Bill

    Kill Bill is an open-source billing and payments platform  # noqa: E501

    OpenAPI spec version: 0.22.22-SNAPSHOT
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import killbill
from killbill.models.overdue_state import OverdueState  # noqa: E501
from killbill.rest import ApiException


class TestOverdueState(unittest.TestCase):
    """OverdueState unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testOverdueState(self):
        """Test OverdueState"""
        # FIXME: construct object with mandatory attributes with example values
        # model = killbill.models.overdue_state.OverdueState()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Kill Bill

    Kill Bill is an open-source billing and payments platform  # noqa: E501

    OpenAPI spec version: 0.22.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class TagDefinition(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'is_control_tag': 'bool',
        'name': 'str',
        'description': 'str',
        'applicable_object_types': 'list[str]',
        'audit_logs': 'list[AuditLog]'
    }

    attribute_map = {
        'id': 'id',
        'is_control_tag': 'isControlTag',
        'name': 'name',
        'description': 'description',
        'applicable_object_types': 'applicableObjectTypes',
        'audit_logs': 'auditLogs'
    }

    def __init__(self, id=None, is_control_tag=None, name=None, description=None, applicable_object_types=None, audit_logs=None):  # noqa: E501
        """TagDefinition - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._is_control_tag = None
        self._name = None
        self._description = None
        self._applicable_object_types = None
        self._audit_logs = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if is_control_tag is not None:
            self.is_control_tag = is_control_tag
        self.name = name
        self.description = description
        if applicable_object_types is not None:
            self.applicable_object_types = applicable_object_types
        if audit_logs is not None:
            self.audit_logs = audit_logs

    @property
    def id(self):
        """Gets the id of this TagDefinition.  # noqa: E501


        :return: The id of this TagDefinition.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this TagDefinition.


        :param id: The id of this TagDefinition.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def is_control_tag(self):
        """Gets the is_control_tag of this TagDefinition.  # noqa: E501


        :return: The is_control_tag of this TagDefinition.  # noqa: E501
        :rtype: bool
        """
        return self._is_control_tag

    @is_control_tag.setter
    def is_control_tag(self, is_control_tag):
        """Sets the is_control_tag of this TagDefinition.


        :param is_control_tag: The is_control_tag of this TagDefinition.  # noqa: E501
        :type: bool
        """

        self._is_control_tag = is_control_tag

    @property
    def name(self):
        """Gets the name of this TagDefinition.  # noqa: E501


        :return: The name of this TagDefinition.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this TagDefinition.


        :param name: The name of this TagDefinition.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def description(self):
        """Gets the description of this TagDefinition.  # noqa: E501


        :return: The description of this TagDefinition.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this TagDefinition.


        :param description: The description of this TagDefinition.  # noqa: E501
        :type: str
        """
        if description is None:
            raise ValueError("Invalid value for `description`, must not be `None`")  # noqa: E501

        self._description = description

    @property
    def applicable_object_types(self):
        """Gets the applicable_object_types of this TagDefinition.  # noqa: E501


        :return: The applicable_object_types of this TagDefinition.  # noqa: E501
        :rtype: list[str]
        """
        return self._applicable_object_types

    @applicable_object_types.setter
    def applicable_object_types(self, applicable_object_types):
        """Sets the applicable_object_types of this TagDefinition.


        :param applicable_object_types: The applicable_object_types of this TagDefinition.  # noqa: E501
        :type: list[str]
        """
        allowed_values = ["ACCOUNT", "ACCOUNT_EMAIL", "BLOCKING_STATES", "BUNDLE", "CUSTOM_FIELD", "INVOICE", "PAYMENT", "TRANSACTION", "INVOICE_ITEM", "INVOICE_PAYMENT", "SUBSCRIPTION", "SUBSCRIPTION_EVENT", "SERVICE_BROADCAST", "PAYMENT_ATTEMPT", "PAYMENT_METHOD", "TAG", "TAG_DEFINITION", "TENANT", "TENANT_KVS"]  # noqa: E501
        if not set(applicable_object_types).issubset(set(allowed_values)):
            raise ValueError(
                "Invalid values for `applicable_object_types` [{0}], must be a subset of [{1}]"  # noqa: E501
                .format(", ".join(map(str, set(applicable_object_types) - set(allowed_values))),  # noqa: E501
                        ", ".join(map(str, allowed_values)))
            )

        self._applicable_object_types = applicable_object_types

    @property
    def audit_logs(self):
        """Gets the audit_logs of this TagDefinition.  # noqa: E501


        :return: The audit_logs of this TagDefinition.  # noqa: E501
        :rtype: list[AuditLog]
        """
        return self._audit_logs

    @audit_logs.setter
    def audit_logs(self, audit_logs):
        """Sets the audit_logs of this TagDefinition.


        :param audit_logs: The audit_logs of this TagDefinition.  # noqa: E501
        :type: list[AuditLog]
        """

        self._audit_logs = audit_logs

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TagDefinition, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TagDefinition):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Kill Bill

    Kill Bill is an open-source billing and payments platform  # noqa: E501

    OpenAPI spec version: 0.22.22-SNAPSHOT
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import killbill
from killbill.api.overdue_api import OverdueApi  # noqa: E501
from killbill.rest import ApiException


class TestOverdueApi(unittest.TestCase):
    """OverdueApi unit test stubs"""

    def setUp(self):
        self.api = killbill.api.overdue_api.OverdueApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_overdue_config_json(self):
        """Test case for get_overdue_config_json

        Retrieve the overdue config as JSON  # noqa: E501
        """
        pass

    def test_get_overdue_config_xml(self):
        """Test case for get_overdue_config_xml

        Retrieve the overdue config as XML  # noqa: E501
        """
        pass

    def test_upload_overdue_config_json(self):
        """Test case for upload_overdue_config_json

        Upload the full overdue config as JSON  # noqa: E501
        """
        pass

    def test_upload_overdue_config_xml(self):
        """Test case for upload_overdue_config_xml

        Upload the full overdue config as XML  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa
"""
    Kill Bill

    Kill Bill is an open-source billing and payments platform  # noqa: E501

    OpenAPI spec version: 0.22.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import models into model package
from killbill.models.account import Account
from killbill.models.account_email import AccountEmail
from killbill.models.account_timeline import AccountTimeline
from killbill.models.admin_payment import AdminPayment
from killbill.models.audit_log import AuditLog
from killbill.models.block_price import BlockPrice
from killbill.models.blocking_state import BlockingState
from killbill.models.bulk_subscriptions_bundle import BulkSubscriptionsBundle
from killbill.models.bundle import Bundle
from killbill.models.bundle_timeline import BundleTimeline
from killbill.models.catalog import Catalog
from killbill.models.combo_hosted_payment_page import ComboHostedPaymentPage
from killbill.models.combo_payment_transaction import ComboPaymentTransaction
from killbill.models.custom_field import CustomField
from killbill.models.duration import Duration
from killbill.models.entity import Entity
from killbill.models.event_subscription import EventSubscription
from killbill.models.hosted_payment_page_fields import HostedPaymentPageFields
from killbill.models.hosted_payment_page_form_descriptor import HostedPaymentPageFormDescriptor
from killbill.models.invoice import Invoice
from killbill.models.invoice_dry_run import InvoiceDryRun
from killbill.models.invoice_item import InvoiceItem
from killbill.models.invoice_payment import InvoicePayment
from killbill.models.invoice_payment_transaction import InvoicePaymentTransaction
from killbill.models.limit import Limit
from killbill.models.node_command import NodeCommand
from killbill.models.node_command_property import NodeCommandProperty
from killbill.models.overdue import Overdue
from killbill.models.overdue_condition import OverdueCondition
from killbill.models.overdue_state import OverdueState
from killbill.models.overdue_state_config import OverdueStateConfig
from killbill.models.payment import Payment
from killbill.models.payment_attempt import PaymentAttempt
from killbill.models.payment_method import PaymentMethod
from killbill.models.payment_method_plugin_detail import PaymentMethodPluginDetail
from killbill.models.payment_transaction import PaymentTransaction
from killbill.models.phase import Phase
from killbill.models.phase_price import PhasePrice
from killbill.models.plan import Plan
from killbill.models.plan_detail import PlanDetail
from killbill.models.plugin_info import PluginInfo
from killbill.models.plugin_property import PluginProperty
from killbill.models.plugin_service_info import PluginServiceInfo
from killbill.models.price import Price
from killbill.models.price_list import PriceList
from killbill.models.product import Product
from killbill.models.role_definition import RoleDefinition
from killbill.models.rolled_up_unit import RolledUpUnit
from killbill.models.rolled_up_usage import RolledUpUsage
from killbill.models.session import Session
from killbill.models.simple_plan import SimplePlan
from killbill.models.subject import Subject
from killbill.models.subscription import Subscription
from killbill.models.subscription_usage_record import SubscriptionUsageRecord
from killbill.models.tag import Tag
from killbill.models.tag_definition import TagDefinition
from killbill.models.tenant import Tenant
from killbill.models.tenant_key_value import TenantKeyValue
from killbill.models.tier import Tier
from killbill.models.tier_price import TierPrice
from killbill.models.tiered_block import TieredBlock
from killbill.models.unit import Unit
from killbill.models.unit_usage_record import UnitUsageRecord
from killbill.models.usage import Usage
from killbill.models.usage_price import UsagePrice
from killbill.models.usage_record import UsageRecord
from killbill.models.user_roles import UserRoles



# coding: utf-8

"""
    Kill Bill

    Kill Bill is an open-source billing and payments platform  # noqa: E501

    OpenAPI spec version: 0.22.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class AdminPayment(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'last_success_payment_state': 'str',
        'current_payment_state_name': 'str',
        'transaction_status': 'str'
    }

    attribute_map = {
        'last_success_payment_state': 'lastSuccessPaymentState',
        'current_payment_state_name': 'currentPaymentStateName',
        'transaction_status': 'transactionStatus'
    }

    def __init__(self, last_success_payment_state=None, current_payment_state_name=None, transaction_status=None):  # noqa: E501
        """AdminPayment - a model defined in Swagger"""  # noqa: E501
        self._last_success_payment_state = None
        self._current_payment_state_name = None
        self._transaction_status = None
        self.discriminator = None
        if last_success_payment_state is not None:
            self.last_success_payment_state = last_success_payment_state
        if current_payment_state_name is not None:
            self.current_payment_state_name = current_payment_state_name
        if transaction_status is not None:
            self.transaction_status = transaction_status

    @property
    def last_success_payment_state(self):
        """Gets the last_success_payment_state of this AdminPayment.  # noqa: E501


        :return: The last_success_payment_state of this AdminPayment.  # noqa: E501
        :rtype: str
        """
        return self._last_success_payment_state

    @last_success_payment_state.setter
    def last_success_payment_state(self, last_success_payment_state):
        """Sets the last_success_payment_state of this AdminPayment.


        :param last_success_payment_state: The last_success_payment_state of this AdminPayment.  # noqa: E501
        :type: str
        """

        self._last_success_payment_state = last_success_payment_state

    @property
    def current_payment_state_name(self):
        """Gets the current_payment_state_name of this AdminPayment.  # noqa: E501


        :return: The current_payment_state_name of this AdminPayment.  # noqa: E501
        :rtype: str
        """
        return self._current_payment_state_name

    @current_payment_state_name.setter
    def current_payment_state_name(self, current_payment_state_name):
        """Sets the current_payment_state_name of this AdminPayment.


        :param current_payment_state_name: The current_payment_state_name of this AdminPayment.  # noqa: E501
        :type: str
        """

        self._current_payment_state_name = current_payment_state_name

    @property
    def transaction_status(self):
        """Gets the transaction_status of this AdminPayment.  # noqa: E501


        :return: The transaction_status of this AdminPayment.  # noqa: E501
        :rtype: str
        """
        return self._transaction_status

    @transaction_status.setter
    def transaction_status(self, transaction_status):
        """Sets the transaction_status of this AdminPayment.


        :param transaction_status: The transaction_status of this AdminPayment.  # noqa: E501
        :type: str
        """

        self._transaction_status = transaction_status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AdminPayment, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AdminPayment):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Kill Bill

    Kill Bill is an open-source billing and payments platform  # noqa: E501

    OpenAPI spec version: 0.22.22-SNAPSHOT
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import killbill
from killbill.api.payment_transaction_api import PaymentTransactionApi  # noqa: E501
from killbill.rest import ApiException


class TestPaymentTransactionApi(unittest.TestCase):
    """PaymentTransactionApi unit test stubs"""

    def setUp(self):
        self.api = killbill.api.payment_transaction_api.PaymentTransactionApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_transaction_custom_fields(self):
        """Test case for create_transaction_custom_fields

        Add custom fields to payment transaction  # noqa: E501
        """
        pass

    def test_create_transaction_tags(self):
        """Test case for create_transaction_tags

        Add tags to payment transaction  # noqa: E501
        """
        pass

    def test_delete_transaction_custom_fields(self):
        """Test case for delete_transaction_custom_fields

        Remove custom fields from payment transaction  # noqa: E501
        """
        pass

    def test_delete_transaction_tags(self):
        """Test case for delete_transaction_tags

        Remove tags from payment transaction  # noqa: E501
        """
        pass

    def test_get_payment_by_transaction_external_key(self):
        """Test case for get_payment_by_transaction_external_key

        Retrieve a payment by transaction external key  # noqa: E501
        """
        pass

    def test_get_payment_by_transaction_id(self):
        """Test case for get_payment_by_transaction_id

        Retrieve a payment by transaction id  # noqa: E501
        """
        pass

    def test_get_transaction_audit_logs_with_history(self):
        """Test case for get_transaction_audit_logs_with_history

        Retrieve payment transaction audit logs with history by id  # noqa: E501
        """
        pass

    def test_get_transaction_custom_fields(self):
        """Test case for get_transaction_custom_fields

        Retrieve payment transaction custom fields  # noqa: E501
        """
        pass

    def test_get_transaction_tags(self):
        """Test case for get_transaction_tags

        Retrieve payment transaction tags  # noqa: E501
        """
        pass

    def test_modify_transaction_custom_fields(self):
        """Test case for modify_transaction_custom_fields

        Modify custom fields to payment transaction  # noqa: E501
        """
        pass

    def test_notify_state_changed(self):
        """Test case for notify_state_changed

        Mark a pending payment transaction as succeeded or failed  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from killbill.api.account_api import AccountApi
from killbill.api.admin_api import AdminApi
from killbill.api.bundle_api import BundleApi
from killbill.api.catalog_api import CatalogApi
from killbill.api.credit_api import CreditApi
from killbill.api.custom_field_api import CustomFieldApi
from killbill.api.export_api import ExportApi
from killbill.api.invoice_api import InvoiceApi
from killbill.api.invoice_item_api import InvoiceItemApi
from killbill.api.invoice_payment_api import InvoicePaymentApi
from killbill.api.nodes_info_api import NodesInfoApi
from killbill.api.overdue_api import OverdueApi
from killbill.api.payment_api import PaymentApi
from killbill.api.payment_gateway_api import PaymentGatewayApi
from killbill.api.payment_method_api import PaymentMethodApi
from killbill.api.payment_transaction_api import PaymentTransactionApi
from killbill.api.plugin_info_api import PluginInfoApi
from killbill.api.security_api import SecurityApi
from killbill.api.subscription_api import SubscriptionApi
from killbill.api.tag_api import TagApi
from killbill.api.tag_definition_api import TagDefinitionApi
from killbill.api.tenant_api import TenantApi
from killbill.api.usage_api import UsageApi



# coding: utf-8

"""
    Kill Bill

    Kill Bill is an open-source billing and payments platform  # noqa: E501

    OpenAPI spec version: 0.22.22-SNAPSHOT
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import killbill
from killbill.api.custom_field_api import CustomFieldApi  # noqa: E501
from killbill.rest import ApiException


class TestCustomFieldApi(unittest.TestCase):
    """CustomFieldApi unit test stubs"""

    def setUp(self):
        self.api = killbill.api.custom_field_api.CustomFieldApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_custom_field_audit_logs_with_history(self):
        """Test case for get_custom_field_audit_logs_with_history

        Retrieve custom field audit logs with history by id  # noqa: E501
        """
        pass

    def test_get_custom_fields(self):
        """Test case for get_custom_fields

        List custom fields  # noqa: E501
        """
        pass

    def test_search_custom_fields(self):
        """Test case for search_custom_fields

        Search custom fields  # noqa: E501
        """
        pass

    def test_search_custom_fields_by_type_name(self):
        """Test case for search_custom_fields_by_type_name

        Search custom fields by type, name and optional value  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Kill Bill

    Kill Bill is an open-source billing and payments platform  # noqa: E501

    OpenAPI spec version: 0.22.22-SNAPSHOT
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import killbill
from killbill.api.payment_method_api import PaymentMethodApi  # noqa: E501
from killbill.rest import ApiException


class TestPaymentMethodApi(unittest.TestCase):
    """PaymentMethodApi unit test stubs"""

    def setUp(self):
        self.api = killbill.api.payment_method_api.PaymentMethodApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_payment_method_custom_fields(self):
        """Test case for create_payment_method_custom_fields

        Add custom fields to payment method  # noqa: E501
        """
        pass

    def test_delete_payment_method(self):
        """Test case for delete_payment_method

        Delete a payment method  # noqa: E501
        """
        pass

    def test_delete_payment_method_custom_fields(self):
        """Test case for delete_payment_method_custom_fields

        Remove custom fields from payment method  # noqa: E501
        """
        pass

    def test_get_payment_method(self):
        """Test case for get_payment_method

        Retrieve a payment method by id  # noqa: E501
        """
        pass

    def test_get_payment_method_audit_logs_with_history(self):
        """Test case for get_payment_method_audit_logs_with_history

        Retrieve payment method audit logs with history by id  # noqa: E501
        """
        pass

    def test_get_payment_method_by_key(self):
        """Test case for get_payment_method_by_key

        Retrieve a payment method by external key  # noqa: E501
        """
        pass

    def test_get_payment_method_custom_fields(self):
        """Test case for get_payment_method_custom_fields

        Retrieve payment method custom fields  # noqa: E501
        """
        pass

    def test_get_payment_methods(self):
        """Test case for get_payment_methods

        List payment methods  # noqa: E501
        """
        pass

    def test_modify_payment_method_custom_fields(self):
        """Test case for modify_payment_method_custom_fields

        Modify custom fields to payment method  # noqa: E501
        """
        pass

    def test_search_payment_methods(self):
        """Test case for search_payment_methods

        Search payment methods  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
